MethodDescriptor

Struct MethodDescriptor 

pub struct MethodDescriptor { /* private fields */ }
A method definition for a ServiceDescriptor.

Implementations

Source

impl MethodDescriptor

pub fn new(service: ServiceDescriptor, index: usize) -> MethodDescriptor

Create a new MethodDescriptor referencing the method at index within the ServiceDescriptor.

Panics

Panics if index is out-of-bounds.

pub fn index(&self) -> usize

Gets the index of the method within the parent ServiceDescriptor.

pub fn parent_service(&self) -> &ServiceDescriptor

Gets a reference to the ServiceDescriptor this method is defined in.

pub fn parent_pool(&self) -> &DescriptorPool

Gets a reference to the DescriptorPool this method is defined in.

pub fn parent_file(&self) -> FileDescriptor

Gets the FileDescriptor this method is defined in.

pub fn name(&self) -> &str

Gets the short name of the method, e.g. method.

pub fn full_name(&self) -> &str

Gets the full name of the method, e.g. my.package.MyService.my_method.

Examples found in repository?
examples/reflection.rs (line 18)
12async fn main() -> Result<()> {
13    let request = ReflectionRequest::new("http://localhost:50051");
14    let desc = ProtoDescriptor::from_reflection(request).await?;
15    let service = &desc.get_services()[0];
16    let method = &desc.get_methods(service)[0];
17    println!("Service: {:}", service.full_name());
18    println!("Method:  {:}", method.full_name());
19    //
20    let mut req = desc.get_request(&method);
21    req.set_address("http://localhost:50051");
22
23    let mut req = desc.get_request(&method);
24    req.set_address("http://localhost:50051");
25
26    Ok(())
27}
More examples
Hide additional examples
examples/metadata.rs (line 19)
11async fn main() -> Result<()> {
12    let desc = ProtoDescriptor::new(
13        vec!["/Users/philippreiter/Rust/wireman/example"],
14        vec!["grpc_simple/debugger.proto"],
15    )?;
16    let service = &desc.get_services()[0];
17    let method = &desc.get_methods(service)[1];
18    println!("Service: {:}", service.full_name());
19    println!("Method:  {:}", method.full_name());
20
21    let mut req = desc.get_request(&method);
22    req.set_address("http://localhost:50051");
23
24    let resp = do_request(&req).await?;
25    println!("\nResponse:\n{:}", resp.message.to_json()?);
26
27    Ok(())
28}
pub fn path(&self) -> &[i32]

Gets the path where this method is defined within the FileDescriptorProto, e.g. [6, 0, 2, 0].

See path for more details on the structure of the path.

pub fn method_descriptor_proto(&self) -> &MethodDescriptorProto

Gets a reference to the raw MethodDescriptorProto wrapped by this MethodDescriptor.

pub fn options(&self) -> DynamicMessage

Decodes the options defined for this MethodDescriptorProto, including any extension options.

pub fn input(&self) -> MessageDescriptor

Gets the MessageDescriptor for the input type of this method.

pub fn output(&self) -> MessageDescriptor

Gets the MessageDescriptor for the output type of this method.

pub fn is_client_streaming(&self) -> bool

Returns true if the client streams multiple messages.

pub fn is_server_streaming(&self) -> bool

Returns true if the server streams multiple messages.

Examples found in repository?
examples/streaming.rs (line 18)
9async fn main() -> Result<()> {
10    let desc = ProtoDescriptor::new(
11        vec!["/Users/philippreiter/Rust/wireman/example/server/streaming"],
12        vec!["streaming.proto"],
13    )?;
14
15    let service = &desc.get_services()[0];
16    let method = &desc.get_methods(service)[0];
17
18    if !method.is_server_streaming() {
19        println!("Method must be server streaming");
20    }
21
22    let mut request = desc.get_request(&method);
23    request.set_address("http://localhost:50051");
24
25    let response = call_server_streaming(&request, None).await?;
26
27    let mut pinned = std::pin::pin!(response);
28    let stream = pinned.as_mut().get_mut();
29
30    while let Some(message) = stream.next().await {
31        let message = message?;
32        println!("message: {:?}", message.message);
33        println!();
34    }
35
36    Ok(())
37}