ServiceDescriptor

Struct ServiceDescriptor 

pub struct ServiceDescriptor { /* private fields */ }
A protobuf service definition.

Implementations

Source

impl ServiceDescriptor

pub fn new(pool: DescriptorPool, index: usize) -> ServiceDescriptor

Create a new ServiceDescriptor referencing the service at index within the given DescriptorPool.

Panics

Panics if index is out-of-bounds.

pub fn index(&self) -> usize

Returns the index of this ServiceDescriptor within the parent DescriptorPool.

pub fn parent_pool(&self) -> &DescriptorPool

Gets a reference to the DescriptorPool this service is defined in.

pub fn parent_file(&self) -> FileDescriptor

Gets the FileDescriptor this service is defined in.

pub fn name(&self) -> &str

Gets the short name of the service, e.g. MyService.

pub fn full_name(&self) -> &str

Gets the full name of the service, e.g. my.package.Service.

Examples found in repository?
examples/reflection.rs (line 17)
12async fn main() -> Result<()> {
13    let request = ReflectionRequest::new("http://localhost:50051");
14    let desc = ProtoDescriptor::from_reflection(request).await?;
15    let service = &desc.get_services()[0];
16    let method = &desc.get_methods(service)[0];
17    println!("Service: {:}", service.full_name());
18    println!("Method:  {:}", method.full_name());
19    //
20    let mut req = desc.get_request(&method);
21    req.set_address("http://localhost:50051");
22
23    let mut req = desc.get_request(&method);
24    req.set_address("http://localhost:50051");
25
26    Ok(())
27}
More examples
Hide additional examples
examples/metadata.rs (line 18)
11async fn main() -> Result<()> {
12    let desc = ProtoDescriptor::new(
13        vec!["/Users/philippreiter/Rust/wireman/example"],
14        vec!["grpc_simple/debugger.proto"],
15    )?;
16    let service = &desc.get_services()[0];
17    let method = &desc.get_methods(service)[1];
18    println!("Service: {:}", service.full_name());
19    println!("Method:  {:}", method.full_name());
20
21    let mut req = desc.get_request(&method);
22    req.set_address("http://localhost:50051");
23
24    let resp = do_request(&req).await?;
25    println!("\nResponse:\n{:}", resp.message.to_json()?);
26
27    Ok(())
28}
pub fn package_name(&self) -> &str

Gets the name of the package this service is defined in, e.g. my.package.

If no package name is set, an empty string is returned.

pub fn path(&self) -> &[i32]

Gets the path where this service is defined within the FileDescriptorProto, e.g. [6, 0].

See path for more details on the structure of the path.

pub fn parent_file_descriptor_proto(&self) -> &FileDescriptorProto

Gets a reference to the FileDescriptorProto in which this service is defined.

pub fn service_descriptor_proto(&self) -> &ServiceDescriptorProto

Gets a reference to the raw ServiceDescriptorProto wrapped by this ServiceDescriptor.

pub fn options(&self) -> DynamicMessage

Decodes the options defined for this ServiceDescriptorProto, including any extension options.

pub fn methods(&self) -> impl ExactSizeIterator

Gets an iterator yielding a MethodDescriptor for each method defined in this service.