Skip to main contentModule client
Source - reflection
- tls
- GrpcClient
- Represents a
gRPC client for making RPC calls.
- call_bidirectional_streaming
- Creates a new
gRPC client and streams messages to a gRPC server,
returning a stream of responses (bidirectional-streaming RPC). - call_client_streaming
- Creates a new
gRPC client and streams messages to a gRPC server,
returning a single response (client-streaming RPC). - call_server_streaming
- Creates a new
gRPC client and sends a message to a gRPC server.
This method is async. - call_unary_async
- Creates a new
gRPC client and sends a message to a gRPC server.
This method is async.